@@ -73,7 +73,10 @@ gboolean connection_supports_proxy (NMConnection *connection);
 gboolean connection_supports_ip4 (NMConnection *connection);
 gboolean connection_supports_ip6 (NMConnection *connection);
 
-NMConnection *vpn_connection_from_file (const char *filename, GError **error);
+NMConnection *connection_import_from_file (const char *filename,
+                                           GType ctype,
+                                           const char *vpn_detail,
+                                           GError **error);
 
 #endif  /* __CONNECTION_HELPERS_H__ */
 
