@@ -18,7 +18,7 @@
 #include "nm-connection-editor.h"
 #include "connection-helpers.h"
 
-G_DEFINE_TYPE (CEPageTeam, ce_page_team, CE_TYPE_PAGE_MASTER)
+G_DEFINE_TYPE (CEPageTeam, ce_page_team, CE_TYPE_PAGE_CONTROLLER)
 
 #define CE_PAGE_TEAM_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CE_TYPE_PAGE_TEAM, CEPageTeamPrivate))
 
@@ -26,7 +26,7 @@ typedef struct {
 	NMSettingTeam *setting;
 	NMSettingWired *wired;
 
-	int slave_arptype;
+	int port_arptype;
 
 	GtkTextView *json_config_widget;
 	GtkWidget *import_config_button;
@@ -290,7 +290,6 @@ team_private_init (CEPageTeam *self)
 
 	ce_spin_default_val (priv->notify_peers_count, -1);
 	ce_spin_default_val (priv->notify_peers_interval, -1);
-	ce_spin_default_val (priv->notify_peers_interval, -1);
 	ce_spin_default_val (priv->mcast_rejoin_count, -1);
 	ce_spin_default_val (priv->mcast_rejoin_interval, -1);
 	ce_spin_default_val (priv->tx_balancing_interval, -1);
@@ -900,29 +899,29 @@ populate_ui (CEPageTeam *self)
 }
 
 static void
-connection_removed (CEPageMaster *master, NMConnection *connection)
+connection_removed (CEPageController *controller, NMConnection *connection)
 {
-	CEPageTeam *self = CE_PAGE_TEAM (master);
+	CEPageTeam *self = CE_PAGE_TEAM (controller);
 	CEPageTeamPrivate *priv = CE_PAGE_TEAM_GET_PRIVATE (self);
 
-	if (!ce_page_master_has_slaves (master))
-		priv->slave_arptype = ARPHRD_VOID;
+	if (!ce_page_controller_has_ports (controller))
+		priv->port_arptype = ARPHRD_VOID;
 }
 
 static void
-connection_added (CEPageMaster *master, NMConnection *connection)
+connection_added (CEPageController *controller, NMConnection *connection)
 {
-	CEPageTeam *self = CE_PAGE_TEAM (master);
+	CEPageTeam *self = CE_PAGE_TEAM (controller);
 	CEPageTeamPrivate *priv = CE_PAGE_TEAM_GET_PRIVATE (self);
 
 	if (nm_connection_is_type (connection, NM_SETTING_INFINIBAND_SETTING_NAME))
-		priv->slave_arptype = ARPHRD_INFINIBAND;
+		priv->port_arptype = ARPHRD_INFINIBAND;
 	else
-		priv->slave_arptype = ARPHRD_ETHER;
+		priv->port_arptype = ARPHRD_ETHER;
 }
 
 static void
-create_connection (CEPageMaster *master, NMConnection *connection)
+create_connection (CEPageController *controller, NMConnection *connection)
 {
 	NMSetting *s_port;
 
@@ -947,7 +946,7 @@ connection_type_filter (FUNC_TAG_NEW_CONNECTION_TYPE_FILTER_IMPL,
 	 * need to check the reverse case here since we don't need to call
 	 * new_connection_dialog() in the InfiniBand case.
 	 */
-	if (   priv->slave_arptype == ARPHRD_ETHER
+	if (   priv->port_arptype == ARPHRD_ETHER
 	    && type == NM_TYPE_SETTING_INFINIBAND)
 		return FALSE;
 
@@ -955,9 +954,9 @@ connection_type_filter (FUNC_TAG_NEW_CONNECTION_TYPE_FILTER_IMPL,
 }
 
 static void
-add_slave (CEPageMaster *master, NewConnectionResultFunc result_func)
+add_port (CEPageController *controller, NewConnectionResultFunc result_func)
 {
-	CEPageTeam *self = CE_PAGE_TEAM (master);
+	CEPageTeam *self = CE_PAGE_TEAM (controller);
 	CEPageTeamPrivate *priv = CE_PAGE_TEAM_GET_PRIVATE (self);
 	GtkWidget *toplevel;
 
@@ -965,7 +964,7 @@ add_slave (CEPageMaster *master, NewConnectionResultFunc result_func)
 	g_return_if_fail (toplevel);
 	g_return_if_fail (gtk_widget_is_toplevel (toplevel));
 
-	if (priv->slave_arptype == ARPHRD_INFINIBAND) {
+	if (priv->port_arptype == ARPHRD_INFINIBAND) {
 		new_connection_of_type (GTK_WINDOW (toplevel),
 		                        NULL,
 		                        NULL,
@@ -973,13 +972,13 @@ add_slave (CEPageMaster *master, NewConnectionResultFunc result_func)
 		                        CE_PAGE (self)->client,
 		                        infiniband_connection_new,
 		                        result_func,
-		                        master);
+		                        controller);
 	} else {
 		new_connection_dialog (GTK_WINDOW (toplevel),
 		                       CE_PAGE (self)->client,
 		                       connection_type_filter,
 		                       result_func,
-		                       master);
+		                       controller);
 	}
 }
 
@@ -1067,10 +1066,10 @@ static void
 ce_page_team_init (CEPageTeam *self)
 {
 	CEPageTeamPrivate *priv = CE_PAGE_TEAM_GET_PRIVATE (self);
-	CEPageMaster *master = CE_PAGE_MASTER (self);
+	CEPageController *controller = CE_PAGE_CONTROLLER (self);
 
-	priv->slave_arptype = ARPHRD_VOID;
-	master->aggregating = TRUE;
+	priv->port_arptype = ARPHRD_VOID;
+	controller->aggregating = TRUE;
 }
 
 static void
@@ -1078,16 +1077,16 @@ ce_page_team_class_init (CEPageTeamClass *team_class)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (team_class);
 	CEPageClass *parent_class = CE_PAGE_CLASS (team_class);
-	CEPageMasterClass *master_class = CE_PAGE_MASTER_CLASS (team_class);
+	CEPageControllerClass *controller_class = CE_PAGE_CONTROLLER_CLASS (team_class);
 
 	g_type_class_add_private (object_class, sizeof (CEPageTeamPrivate));
 
 	/* virtual methods */
 	parent_class->ce_page_validate_v = ce_page_validate_v;
-	master_class->create_connection = create_connection;
-	master_class->connection_added = connection_added;
-	master_class->connection_removed = connection_removed;
-	master_class->add_slave = add_slave;
+	controller_class->create_connection = create_connection;
+	controller_class->connection_added = connection_added;
+	controller_class->connection_removed = connection_removed;
+	controller_class->add_port = add_port;
 }
 
 
